summaryrefslogtreecommitdiffstats
path: root/kstars/kstars/indi/lx200gps.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kstars/kstars/indi/lx200gps.cpp')
-rw-r--r--kstars/kstars/indi/lx200gps.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/kstars/kstars/indi/lx200gps.cpp b/kstars/kstars/indi/lx200gps.cpp
index 451a7269..158cd14a 100644
--- a/kstars/kstars/indi/lx200gps.cpp
+++ b/kstars/kstars/indi/lx200gps.cpp
@@ -42,7 +42,7 @@ static ISwitch AzRaBackSlashS[] = {{ "Activate", "", ISS_OFF, 0, 0}};
static ISwitch OTAUpdateS[] = {{ "Update", "", ISS_OFF, 0, 0}};
static ISwitchVectorProperty GPSPowerSw = { mydev, "GPS Power", "", GPSGroup, IP_RW, ISR_1OFMANY, 0 , IPS_IDLE, GPSPowerS, NARRAY(GPSPowerS), "", 0};
-static ISwitchVectorProperty GPSStatusSw = { mydev, "GPS Status", "", GPSGroup, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, GPSStatusS, NARRAY(GPSStatusS), "", 0};
+static ISwitchVectorProperty GPSStatusSw = { mydev, "GPS tqStatus", "", GPSGroup, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, GPSStatusS, NARRAY(GPSStatusS), "", 0};
static ISwitchVectorProperty GPSUpdateSw = { mydev, "GPS System", "", GPSGroup, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, GPSUpdateS, NARRAY(GPSUpdateS), "", 0};
static ISwitchVectorProperty AltDecPecSw = { mydev, "Alt/Dec PEC", "", GPSGroup, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, AltDecPecS, NARRAY(AltDecPecS), "", 0};
static ISwitchVectorProperty AzRaPecSw = { mydev, "Az/Ra PEC", "", GPSGroup, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, AzRaPecS, NARRAY(AzRaPecS), "", 0};
@@ -83,7 +83,7 @@ void LX200GPS::ISGetProperties (const char *dev)
if (dev && strcmp (thisDevice, dev))
return;
-// process parent first
+// process tqparent first
LX200_16::ISGetProperties(dev);
IDDefSwitch (&GPSPowerSw, NULL);
@@ -139,7 +139,7 @@ void LX200GPS::ISNewNumber (const char *dev, const char *name, double values[],
return;
}
/* GPS Status Update */
if (!strcmp(name,GPSStatusSw.name))
{
if (checkPower(&GPSStatusSw))
@@ -334,7 +334,7 @@ void LX200GPS::ISNewNumber (const char *dev, const char *name, double values[],
//getOTATemp(&OTATemp.np[0].value);
//IDSetNumber(&OTATemp, NULL);
- // process parent
+ // process tqparent
LX200_16::getBasicData();
}
@@ -139,7 +139,7 @@ void LX200GPS::ISNewNumber (const char *dev, const char *name, double values[],
return;
}
- /* GPS Status Update */
+ /* GPS tqStatus Update */
if (!strcmp(name,GPSStatusSw.name))
{